# diagrid dev run

Run your code and/or establish local connectivity from 1+ id(s)

### Description

Run your code, establish local connectivity from 1+ id(s) or use a combination of the two actions for a flexible development experience using the Catalyst APIs

```
diagrid dev run [flags]
```

### Examples

```

  # Configure running and/or connecting to multiple applications using the Multi-app Run template file 
  diagrid dev run --project myproj --file myproject.yaml

  # Show the resources that would be created or used by the run file without making changes 
  diagrid dev run --project myproj --file myproject.yaml --dry-run

  # Run a local go application without a local app connection (inbound Catalyst connectivity only)
  diagrid dev run --project myproj --id publisher -- go run ./cmd/publisher/main.go

  # Run a go application and create a local app connection from specified id to localhost:8080 (inbound/outbound Catalyst connectivity)
  diagrid dev run --id subscriber --app-port 8080 -- go run ./cmd/subscriber/main.go

  # Create a local app connection from specified id to localhost:8080 (app can be launched manually, via debugger, etc.)
  diagrid dev run --id subscriber --app-port 8080

```

### Options

```
      --app-dir-path string               Path to the application code (default ".")
      --app-health-check-path string      Path used for health checks; HTTP only (default "/healthz")
      --app-health-probe-interval int32   Interval to probe for the health of the app in seconds (default 5)
      --app-health-probe-timeout int32    Timeout for app health probes in milliseconds (default 500)
      --app-health-threshold int32        Number of consecutive failures for the app to be considered unhealthy (default 3)
      --app-host string                   The host your application is listening on (default "localhost")
      --app-id-env-server-enabled         Enable the id environment server
      --app-id-env-server-port int        Port for the id environment server (default 8001)
      --app-log-destination string        Output destination for application logs. Supported values: file, console or all
  -p, --app-port int                      The port your application is listening on
      --app-protocol string               Protocol used to interact with the app endpoint (HTTP or gRPC). Defaults to http (default "http")
      --approve                           Approve the deployment of the dapr run file in the current project
      --dry-run                           Show what would happen, but do not modify resources
      --enable-api-logging                Enable the logging of all API calls from application
      --enable-app-health-check           Enable application health checks
  -e, --env stringArray                   Environment variables needed by your application at runtime
  -f, --file string                       Path to the Dapr multi-app run file
  -h, --help                              help for run
  -a, --id string                         id associated to the local application
      --project string                    Project to use for the dev session
      --rm-appids                         Delete any ids that were created during this dev run (does not delete pre-existing ids)
      --shutdown-timeout duration         Grace period to let your app shut down cleanly (e.g. de-register from the agent registry) after Ctrl-C before it is force-killed (default 10s)
      --skip-default-resiliency           Skip automatic creation of default service invocation resiliency policy
      --skip-managed-kv                   Skip automatic creation of managed KV Store when provisioning new ids
      --skip-managed-pubsub               Skip automatic creation of managed Pub/Sub when provisioning new ids
      --skip-managed-workflow             Skip automatic enablement of the Diagrid managed workflow store when provisioning new ids
  -y, --yes                               Skip confirmation prompt
```

### Options inherited from parent commands

```
      --api-key string   Diagrid Cloud API key
```

### SEE ALSO

- [diagrid dev](./dev.md)	 - Run local code against Catalyst APIs
